##  Limitations
  * Diagram templates contain only fact sheet types and relation shapes. The system doesn't support free-form shapes or images.
  * You can generate diagrams from diagram templates only on the template preview page. You can't generate diagrams from the inventory, the diagrams overview, or existing diagrams.
